@@ -7,8 +7,11 @@ import time
 import unittest
 import logging
 
-config = bakthat.config
-log = logging.getLogger(__name__)
+from bakthat.conf import config, DEFAULT_DESTINATION, DEFAULT_LOCATION
+from bakthat.backends import GlacierBackend
+
+log = logging.getLogger()
+logging.basicConfig(level=logging.DEBUG)
 
 class BakthatTestCase(unittest.TestCase):
 
@@ -116,7 +119,7 @@ class BakthatTestCase(unittest.TestCase):
 
             # We initialize glacier backend 
             # to check that the file appear in both local and remote (S3) inventory
-            glacier_backend = bakthat.GlacierBackend(None)
+            glacier_backend = GlacierBackend(None)
             
             archives = glacier_backend.load_archives()
             archives_s3 = glacier_backend.load_archives_from_s3()
@@ -127,8 +130,8 @@ class BakthatTestCase(unittest.TestCase):
             # Next we check that the file is stored in both inventories
             inventory_key_name = bakthat.match_filename(self.test_filename, "glacier")[0]["key"]
 
-            self.assertTrue(inventory_key_name in archives)
-            self.assertTrue(inventory_key_name in archives_s3)
+            self.assertTrue(inventory_key_name in [a.get("filename") for a in archives])
+            self.assertTrue(inventory_key_name in [a.get("filename") for a in archives_s3])
 
             # Restore backup
             job = bakthat.restore(self.test_filename, "glacier", job_check=True)
